@@ -25,7 +25,7 @@
 "bgpllm" <-
 function(X, Z, XX=NULL, bprior="bflat", corr="expsep", gamma=c(10,0.2,0.7),
          BTE=c(1000,4000,2), R=1, m0r1=FALSE, pred.n=TRUE, ds2x=FALSE,
-         ego=FALSE)
+         ego=FALSE, nu=0.5)
 {
   n <- dim(X)[1]
   if(is.null(n)) { n <- length(X); X <- matrix(X, nrow=n); d <- 1 }
@@ -35,6 +35,7 @@ function(X, Z, XX=NULL, bprior="bflat", corr="expsep", gamma=c(10,0.2,0.7),
   params$corr <- corr
   params$gamma <- gamma
   params$tree <- c(0,0,10)	# no tree
+  if(corr == "matern"){ params$nu <- nu; }
   return(tgp(X,Z,XX,BTE,R,m0r1,FALSE,params,pred.n,ds2x,ego))
 }
 
