@@ -41,6 +41,7 @@ extern "C"
 #include <assert.h>
 #include <string.h>
 #include <string>
+#include <fstream>
 using namespace std;
 
 #define BUFFMAX 256
@@ -611,12 +612,55 @@ void ExpSep_Prior::read_double(double *dparams)
   if((int) dparams[0] == -1)
     { fix_d = true; /*myprintf(stdout, "fixing d prior\n");*/ }
   else {
+    fix_d = false;
     get_mix_prior_params_double(d_alpha_lambda, d_beta_lambda, dparams, "d lambda");
   }
   dparams += 4; /* reset */
 }
 
 
+/*
+ * read_ctrlfile:
+ *
+ * read prior parameterization from a control file
+ */
+
+void ExpSep_Prior::read_ctrlfile(ifstream *ctrlfile)
+{
+  char line[BUFFMAX], line_copy[BUFFMAX];
+
+  /* read the parameters that have to do with the
+   * nugget first */
+  read_ctrlfile_nug(ctrlfile);
+
+  /* read the d parameter from the control file */
+  ctrlfile->getline(line, BUFFMAX);
+  d[0] = atof(strtok(line, " \t\n#"));
+  for(unsigned int i=1; i<col-1; i++) d[i] = d[0];
+  myprintf(stdout, "starting d=", d);
+  printVector(d, col-1, stdout);
+
+  /* read d and nug-hierarchical parameters (mix of gammas) */
+  double alpha[2], beta[2];
+  ctrlfile->getline(line, BUFFMAX);
+  get_mix_prior_params(alpha, beta, line, "d");
+  for(unsigned int i=0; i<col-1; i++) {
+    dupv(d_alpha[i], alpha, 2);
+    dupv(d_beta[i], beta, 2);
+  }
+
+  /* d hierarchical lambda prior parameters */
+  ctrlfile->getline(line, BUFFMAX);
+  strcpy(line_copy, line);
+  if(!strcmp("fixed", strtok(line_copy, " \t\n#")))
+    { fix_d = true; myprintf(stdout, "fixing d prior\n"); }
+  else {
+    fix_d = false;
+    get_mix_prior_params(d_alpha_lambda, d_beta_lambda, line, "d lambda");  
+  }
+}
+
+
 /*
  * default_d_priors:
  * 
